==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/HomeButton.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author James Johnson
 */

/* jshint browser: true */ /* eslint-env browser */

/* globals niagara */

/**
 * API Status: **Private**
 * @module nmodule/vykonPro/rc/ux/HomeButton
 */
define(['baja!', 'baja!bajaui:Halign', 'bajaux/spandrel', 'jquery', 'Promise', 'nmodule/bajaui/rc/ux/Button', 'lex!vykonPro'], function (baja, types, spandrel, $, Promise, Button, lexs) {
  'use strict';

  var _lexs = _slicedToArray(lexs, 1),
    lex = _lexs[0],
    widgetDefaults = function widgetDefaults() {
      return {
        properties: {
          rootCssClass: 'ux-Button ux-HomeButton',
          text: lex.get('commands.home.label'),
          textOverride: baja.$('baja:Format', '')
        }
      };
    };

  /**
   *
   *
   * @class
   * @alias module:nmodule/vykonPro/rc/ux/HomeButton
   * @extends module:nmodule/bajaui/rc/ux/Button
   */
  return /*#__PURE__*/function (_spandrel) {
    function HomeButton(params) {
      _classCallCheck(this, HomeButton);
      return _callSuper(this, HomeButton, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }

    /**
     * @returns {Promise}
     */
    _inherits(HomeButton, _spandrel);
    return _createClass(HomeButton, [{
      key: "doInvokeAction",
      value: function doInvokeAction(e) {
        niagara.env.hyperlink(baja.getUserHome());
        return _get(_getPrototypeOf(HomeButton.prototype), "doInvokeAction", this).apply(this, arguments);
      }
    }, {
      key: "render",
      value: function render() {
        //TODO: NCCB-45981 - Possibly remove this workaround after we fix this problem for all inputs in spandral?
        // would also be nice to leave this render override out, but Button.render does NOT get called for ToggleButton
        //when there is a click of the input
        return Button.prototype.render.apply(this, arguments);
      }
    }]);
  }(spandrel(function (value, _ref) {
    var properties = _ref.properties,
      renderSuper = _ref.renderSuper;
    return resolveTextOverride(properties).then(function (text) {
      return renderSuper(function (state) {
        state.properties.text = text;
        return state;
      });
    });
  }, {
    "extends": Button
  }));

  /**
   * @returns {Promise}
   */
  function resolveTextOverride(properties) {
    var text = properties.text,
      textOverride = properties.textOverride;
    if (!textOverride.equals(baja.Format.DEFAULT)) {
      return textOverride.format({
        object: baja.$('baja:Component', properties)
      });
    } else {
      return Promise.resolve(text);
    }
  }
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/HomeButton.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author James Johnson
 */

/* jshint browser: true */ /* eslint-env browser */

/* globals niagara */

/**
 * API Status: **Private**
 * @module nmodule/vykonPro/rc/ux/HomeButton
 */
define(['baja!', 'baja!bajaui:Halign', 'bajaux/spandrel', 'jquery', 'Promise', 'nmodule/bajaui/rc/ux/Button', 'lex!vykonPro'], function (baja, types, spandrel, $, Promise, Button, lexs) {
  'use strict';

  var _lexs = _slicedToArray(lexs, 1),
    lex = _lexs[0],
    widgetDefaults = function widgetDefaults() {
      return {
        properties: {
          rootCssClass: 'ux-Button ux-HomeButton',
          text: lex.get('commands.home.label'),
          textOverride: baja.$('baja:Format', '')
        }
      };
    };

  /**
   *
   *
   * @class
   * @alias module:nmodule/vykonPro/rc/ux/HomeButton
   * @extends module:nmodule/bajaui/rc/ux/Button
   */
  return /*#__PURE__*/function (_spandrel) {
    function HomeButton(params) {
      _classCallCheck(this, HomeButton);
      return _callSuper(this, HomeButton, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }

    /**
     * @returns {Promise}
     */
    _inherits(HomeButton, _spandrel);
    return _createClass(HomeButton, [{
      key: "doInvokeAction",
      value: function doInvokeAction(e) {
        niagara.env.hyperlink(baja.getUserHome());
        return _superPropGet(HomeButton, "doInvokeAction", this, 3)(arguments);
      }
    }, {
      key: "render",
      value: function render() {
        //TODO: NCCB-45981 - Possibly remove this workaround after we fix this problem for all inputs in spandral?
        // would also be nice to leave this render override out, but Button.render does NOT get called for ToggleButton
        //when there is a click of the input
        return Button.prototype.render.apply(this, arguments);
      }
    }]);
  }(spandrel(function (value, _ref) {
    var properties = _ref.properties,
      renderSuper = _ref.renderSuper;
    return resolveTextOverride(properties).then(function (text) {
      return renderSuper(function (state) {
        state.properties.text = text;
        return state;
      });
    });
  }, {
    "extends": Button
  }));

  /**
   * @returns {Promise}
   */
  function resolveTextOverride(properties) {
    var text = properties.text,
      textOverride = properties.textOverride;
    if (!textOverride.equals(baja.Format.DEFAULT)) {
      return textOverride.format({
        object: baja.$('baja:Component', properties)
      });
    } else {
      return Promise.resolve(text);
    }
  }
});
